#
# spec file for package etcd-for-k8s1.29
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define project go.etcd.io/etcd

Name:           etcd-for-k8s1.29
Version:        3.5.12
Release:        1.1
Summary:        Etcd and etcdtl for k8s image
License:        Apache-2.0
Group:          System/Management
URL:            https://github.com/etcd-io/etcd
Source:         etcd-%{version}.tar.gz
Source1:        vendor-etcdctl.tar.gz
Source2:        vendor-server.tar.gz
BuildRequires:  golang-packaging
BuildRequires:  golang(API) >= 1.20
ExcludeArch:    %ix86
ExcludeArch:    s390
Conflicts:      etcd
Conflicts:      etcdctl
Provides:       etcd-for-k8s = %{version}
Conflicts:      etcd-for-k8s

%description
etcd is a distributed, consistent key-value store for shared configuration and
service discovery. This package contains different versions of etcd and
etcdctl for the kubernetes container image.

%prep
%setup -q -n etcd-%{version}

%build
%{goprep} %{project}

tar -xf %{SOURCE1} -C ./etcdctl
tar -xf %{SOURCE2} -C ./server

mkdir ./bin

cd ./etcdctl
go build -v -buildmode=pie -mod=vendor -o ../bin/etcdctl
cd ..

cd ./server
go build -v -buildmode=pie -mod=vendor -o ../bin/etcd
cd ..

%install
install -d %{buildroot}/%{_bindir}
install -d %{buildroot}/%{_sbindir}
install -D -p -m 0755 bin/etcdctl %{buildroot}%{_bindir}/etcdctl-%{version}
install -D -p -m 0755 bin/etcd %{buildroot}%{_sbindir}/etcd-%{version}

ln -sf etcdctl-%{version} %{buildroot}%{_bindir}/etcdctl
# ln -sf etcd-%{version} %{buildroot}%{_sbindir}/etcd
# we need a wrapper script to be able to set some environment variables.
echo "#!/bin/bash" > %{buildroot}%{_sbindir}/etcd
%ifarch aarch64
echo "export ETCD_UNSUPPORTED_ARCH=arm64" >> %{buildroot}%{_sbindir}/etcd
%endif
echo "exec %{_sbindir}/etcd-%{version} \"\$@\"" >> %{buildroot}%{_sbindir}/etcd
chmod 755 %{buildroot}%{_sbindir}/etcd

%files
%defattr(-,root,root)
%license LICENSE
%{_sbindir}/etcd
%{_sbindir}/etcd-%{version}
%{_bindir}/etcdctl
%{_bindir}/etcdctl-%{version}

%changelog
* Mon Apr  8 2024 priyanka.saggu@suse.com
- Update to version 3.5.12:
  * Bump golang.org/x/crypto to v0.17+ to address CVE-2023-48795
  * test: fix TestHashKVWhenCompacting: ensure all goroutine finished
  * print error log when creating peer listener failed
  * mvcc: Printing etcd backend database related metrics inside scheduleCompaction function
  * dependency: update go version to 1.20.13
  * commit bbolt transaction if there is any pending deleting operations
  * add tests to test tx delete consistency.
  * Don't flock snapshot files
  * Backport adding digest for etcd base image.
  * Add a unit tests and missing flags in etcd help.
  * Add missing flag in etcd help.
  * Backport testutils.ExecuteUntil to 3.5 branch
  * member replace e2e test
  * Check if be is nil to avoid panic when be is overriden with nil by recoverSnapshotBackend on line 517
  * Don't redeclare err and snapshot variable, fixing validation of consistent index and closing database on defer
  * test: enable gofail in release e2e test.
  * [3.5] backport health check e2e tests.
  * etcdserver: add linearizable_read check to readyz.
  * etcd: Update go version to 1.20.12
  * tests: Extract e2e cluster setup to separate package
  * server: disable redirects in peer communication
  * etcdserver: add metric counters for livez/readyz health checks.
  * etcdserver: add livez and ready http endpoints for etcd.
  * http health check bug fixes
  * server: Split metrics and health code
  * server: Cover V3 health with tests
  * server: Refactor health checks
  * server: Run health check tests in subtests
  * server: Rename test case expect fields
  * server: Use named struct initialization in healthcheck test
  * Backport server: Don't follow redirects when checking peer urls.
  * Backport embed: Add tracing integration test.
  * Backport server: Have tracingExporter own resources it initialises.
  * Backport server: Add sampling rate to distributed tracing.
  * upgrade github.com/stretchr/testify,google.golang.org/genproto/googleapis/api,google.golang.org/grpc to make it consistent
  * CVE-2023-47108: Backport go.opentelemetry.io/otel@v1.20.0 and go.opentelemetry.io/contrib/instrumentation/google.golang.org/grpc/otelgrpc@v0.46.0
  * github workflow: run arm64 tests on every push
  * etcd: upgrade go version from 1.20.10 to 1.20.11
* Wed Jan 24 2024 Priyanka Saggu <priyanka.saggu@suse.com>
- Update to version 3.5.10:
  * bump bbolt to 1.3.8 for etcd 3.5
  * 3.5: upgrade gRPC-go to 1.58.3
  * Backport corrupt check test fix "etcd server shouldn't wait for the ready notification infinitely on startup"
  * etcdserver: add cluster id check for hashKVHandler
  * [release-3.5]: upgrade gRPC-go to v1.52.0
  * backport #14125 to release-3.5: Update to grpc-1.47 (and fix the connection-string format)
  * Return to default write scheduler since golang.org/x/net@v0.11.0 started using round robin
  * Bump go to v1.20.10 Part of https://github.com/etcd-io/etcd/issues/16740
  * bump golang.org/x/net to 0.17.0 Part of https://github.com/etcd-io/etcd/issues/16740
  * etcd: upgrade go version to 1.20.9
  * Remove obsolete http 1.0 version.
  * fix:Ensure that go version is only defined in one file for release-3.5
  * Fix panic in etcd validate secure endpoints
  * Backport redirect metrics data into file to reduce output.
  * test.sh: increase timeout for grpcproxy test
  * test: add v3 curl test to cover maintenance hash/hashkv REST API
  * api: fix duplicate gateway url issue
  * pkg: add a verification on the pagebytes which must be > 0
  * tests: Backport deflake for TestWatchDelay
  * tests: Backport deflake for TestPageWriterRandom
  * Backport adding unit test for socket options.
  * Backport export reuse-port and reuse-address
  * Fix goword failure in rafthttp/transport.go.
  * Backport update to golang 1.20 minor release.
  * Update workflows to use makefile recipes for unit, integration & e2e-release.
  * Backport Makefile recipes for common test commands.
  * pkg/flags: fix UniqueURLs'Set to remove duplicates in UniqueURLs'uss
  * Backport fix to e2e release version identifcation.
  * Backport #14368 to v3.5
  * Follow up https://github.com/etcd-io/etcd/pull/16068#discussion_r1263667496
  * etcdserver: backport check scheduledCompactKeyName and finishedCompactKeyName before writing hash to release-3.5.
  * Backport #13577 Disable auth gracefully without impacting existing watchers.
  * bump go version to 1.19.11 to fix CVE GO-2023-1878
  * clientv3: create keepAliveCtxCloser goroutine only if ctx can be canceled
  * [3.5] etcdutl: fix db double closed
  * clientv3: remove v3.WithFirstKey() in Barrier.Wait()
  * update etcdctl flag description for snapshot restores
  * etcdutl: update description for --mark-compacted and --bump-revision flags in snapshot restore command
  * Adding optional revision bump and mark compacted to snapshot restore
  * Revert "Merge pull request #16119 from natusameer/release-3.5"
  * Add e2e-arm64.yaml and tests-arm64.yaml to release-3.5 scheduled at 1.30
  * Backport .github/workflows: Read .go-version as a step and not separate workflow.
  * Add first unit test for authApplierV3
  * Early exit auth check on lease puts
  * remove stack log when etcdutl restore
  * etcdserver: fix corruption check when server has just been compacted
  * replace gobin with go install
  * [3.5] Backport updating go to latest patch release 1.19.10
  * add compact hash check to help
  * Fix test of clientv3/naming
  * clientv3/naming/endpoints: fix endpoints prefix bug fixes bug with multiple endpoints with same prefix
  * grpcproxy: fix memberlist results not update when proxy node down
* Wed Jan 24 2024 Priyanka Saggu <priyanka.saggu@suse.com>
- Initial package version 3.5.10:
  * Version specified in kubernetes v1.29.1 https://github.com/kubernetes/kubernetes/blob/v1.29.1/build/dependencies.yaml#L65
